@@ -270,7 +270,7 @@ static void add_player_selection_box(GtkWidget *parent, plugin_data *pd) {
 	}
 	if (player_control_has_library("audacious")) {
 		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter, 0, PLAYER_AUDACIOUS, 1, "Audacious", -1);
+		gtk_list_store_set(store, &iter, 0, PLAYER_AUDACIOUS, 1, "Audacious (<=1.3.x)", -1);
 		if (pd->player == PLAYER_AUDACIOUS)
 			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(combo), &iter);
 	}
