@@ -280,18 +280,20 @@ static void vol_pbar_pressed(GtkWidget *widget, GdkEventButton *event, gpointer
 /* Set song title in tooltip and scrolled label */
 /************************************************/
 void set_song_title(plugin_data *pd) {
-	gchar    *title, *tooltip, *label;
+	gchar    *title, *title_orig, *tooltip, *label;
 	gint     pos, time;
 	gboolean running = pd->pctrl->player_is_running(pd->xmms_session);
+	gboolean valid;
 
 	if (running) {
 		pos        = pd->pctrl->player_get_playlist_pos(pd->xmms_session);
 		time       = pd->pctrl->player_get_playlist_time(pd->xmms_session, pos) / 1000;
-		title      = pd->pctrl->player_get_playlist_title(pd->xmms_session, pos);
+		title	   = pd->pctrl->player_get_playlist_title(pd->xmms_session, pos);
+				
 		if (pd->simple_title)
-			tooltip = g_strdup_printf("%s", title);
+			tooltip = g_strdup_printf("%s", g_locale_to_utf8 (title, -1, NULL, NULL, NULL));
 		else
-			tooltip = g_strdup_printf("%d: %s (%d:%02d)", pos+1, title, time/60, time%60);
+			tooltip = g_strdup_printf("%d: %s (%d:%02d)", pos+1, g_locale_to_utf8 (title, -1, NULL, NULL, NULL), time/60, time%60);
 	}
 	else
 		tooltip = g_strdup_printf(TITLE_STRING);
