@@ -28,6 +28,12 @@
 #ifndef XMMS_PLUGIN_H
 #define XMMS_PLUGIN_H
 
+#include <gtk/gtk.h>
+
+#include <libxfce4panel/xfce-panel-plugin.h>
+
+#include "playerctrl.h"
+
 #define DOEXPAND TRUE
 #define DOFILL   TRUE
 #define PADDING  0
@@ -37,10 +43,11 @@
 #define PAUS (DATA_DIR "/xmms-plugin-pause.png")
 #define STOP (DATA_DIR "/xmms-plugin-stop.png")
 #define NEXT (DATA_DIR "/xmms-plugin-next.png")
+#define MENU (DATA_DIR "/xmms-plugin-menu.png")
 
 #define MAX_SCROLL_SPEED 20             /* limits and default for scroll steps per second */
 #define MIN_SCROLL_SPEED 1
-#define SCROLL_SPEED     5
+#define SCROLL_SPEED     10
 
 #define MAX_SCROLL_DELAY 10             /* limits and default for delay in seconds before */
 #define MIN_SCROLL_DELAY 0              /* scrolling starts                               */
@@ -60,7 +67,7 @@
 
 /* data structure to hold all required data for the plugin */
 typedef struct {
-  GtkWidget      	*boxMain, *boxV, *pbar, *vol_pbar, *viewport, *label;
+  GtkWidget      	*boxMain, *boxV, *pbar, *vol_pbar, *viewport, *label, *menu_btn;
   XfcePanelPlugin 	*base;
   GtkTooltips    *tooltip;
   PangoAttribute *labelattr;
@@ -70,7 +77,19 @@ typedef struct {
   gint           xmms_session;
   guint          timeout;
   gboolean       xmmsvisible, show_mw, show_pl, show_eq, timer_reset,
-                 show_scrolledtitle, quit_xmms, simple_title, pbar_visible, vol_pbar_visible, use_bmp, hor_vol_if_vertical;
+                 show_scrolledtitle, quit_xmms, simple_title, pbar_visible, vol_pbar_visible, hor_vol_if_vertical, menu_btn_visible;
+  Players        player;	/// @see playerctrl.h
+  PlayerCtrl     *pctrl;
 } plugin_data;
 
+/**
+ * Set song title in tooltip and scrolled label
+ */
+void set_song_title(plugin_data *pd);
+
+/**
+ * Adjust the position of volume bar
+ */
+void adjust_vol_pbar(plugin_data *pd);
+
 #endif
